Horizon Style Commandments
==========================

- Step 1: Read the OpenStack Style Commandments
  https://docs.openstack.org/hacking/latest/
- Step 2: Read [hacking] section in tox.ini to find the list of names which
  can be imported directly without triggering the "H302: import only modules"
  flake8 warning
- Step 3: Read on

Horizon Specific Commandments
-----------------------------

- Read the Horizon contributing documentation at
  https://docs.openstack.org/horizon/latest/contributor/contributing.html
- [M322] Method's default argument shouldn't be mutable.
